==> haskell-edisonapi-1.3.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-26D4i6DiKfNNG9Npbqu2a
key: EdisonAPI-1.3.1-26D4i6DiKfNNG9Npbqu2a
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym
abi: 147719965d57bdabe2f34a1af70377d9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-26D4i6DiKfNNG9Npbqu2a
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisonapi-1.3.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi
key: EdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym
abi: a64dc82fb95a00fd8af427350369a2fd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
